@@ -88,10 +88,10 @@ int main(int argc, char **argv)
 
     // see if we are starting with session management
     if (app.isSessionRestored()) {
-        RESTORE(KLettres)
+        kRestoreMainWindows<KLettres>();
     } else {
         // no session.. just start up normally
-        if (parser.positionalArguments().count() == 0) {
+        if (parser.positionalArguments().isEmpty()) {
             KLettres *widget = new KLettres;
             widget->show();
         } else {
